<?php
/**
 * Дополнительные функции и данные для шаблона ubuntu-portal
 *
 * @license    GPL 3 (http://www.gnu.org/licenses/gpl.html)
 * @author     Vadim Nevorotin <malamut@ubuntu.ru>
 */

# Общие файлы для всех ресурсов ubuntu.ru
if (!defined('PORTAL_DIR')) {
	define('PORTAL_DIR', DOKU_TPLINC . 'portal/');
}

# Подгружаем файл общих настроек для всего ubuntu.ru и создаём экземпляр класса настроек
require_once(PORTAL_DIR.'ubuntu-portal.php');

$ubuntu_portal = new ubuntu_portal( DOKU_TPL.'portal/' );

# Подгружаем файлы локализации
require_once(DOKU_TPLINC.'lang/en/lang.php');
if ( $conf['lang'] && $conf['lang'] != 'en' )
		@include_once(DOKU_TPLINC.'lang/'.$conf['lang'].'/lang.php');

/*
 * Функция возвращает первый заголовок текущей страницы Doku, или же
 * в случае его отсутствия - имя страницы
 *
 * @author Vadim Nevorotin (malamut@ubuntu.ru)
*/
function tpl_getTitle() {
	if (!defined('DOKU_INC')) return "";
	
	global $INFO;
	
	$pagetitle = p_get_first_heading($INFO['id']);
	if ($pagetitle) {
		return hsc($pagetitle);
	} else {
		return $INFO['id'];
	}
}

/*
 * Замена стандартной функции tpl_userinfo() на функцию, показывающую ссылку на профиль пользователя
 *
 * @author Vadim Nevorotin (malamut@ubuntu.ru)
*/
function tpl_extUserinfo() {
	if (!defined('DOKU_INC')) return "";
	
	global $lang;
	global $auth;
	global $conf;
	
	if (!plugin_isdisabled('userlink')) {
    	$userlink =& plugin_load('helper', 'userlink');
    	if ($userlink->getConf('use_main_auth') or $userlink->getConf('authmodule') == $conf['authtype']) {
			if (isset($_SERVER['REMOTE_USER'])) {
				print $lang['loggedinas'].': '.$userlink->renderProfileLink($auth->getUserData($_SERVER['REMOTE_USER'], false), 'top').' (';
				tpl_actionlink('login');
				print ')';
				return true;
			}
		}
	}
	return tpl_userinfo();
}

/*
 * Функция пытается показать страницу $pagename.
 *
 * Если $look_up установлен в true, то указанная страница последовательно
 * ищется в родительских пространствах имён, вплоть до корневого.
 *
 * @author Vadim Nevorotin (malamut@ubuntu.ru)
*/
function tpl_showPage($pagename, $look_up = false) {
	global $INFO;
	global $lang;
	
	$pagename = cleanID($pagename);

	if ($look_up && !empty($INFO['namespace'])) {
		$exists = false;
		$namespaces = explode(':', $INFO['namespace']);
		while(count($namespaces) > 0 && !$exists) {
			$pageID = implode(':', $namespaces) . ':' . $pagename;
			$exists =  @file_exists(wikiFN($pageID));
			array_pop($namespaces);
		}
		if (!$exists) {
			$pageID = $pagename;
			$exists = @file_exists(wikiFN($pageID));
		}
	}
	else {
		if (!empty($INFO['namespace']))
			$pageID = $INFO['namespace'] . ':' . $pagename;
		else
			$pageID = $pagename;
		$exists = @file_exists(wikiFN($pageID));
	}
	
	if ($exists && auth_quickaclcheck($pageID) >= AUTH_READ) {
		$xhtml = p_wiki_xhtml($pageID, '', false);
		// Добавляем кнопочку редактирования если можем редактировать
		if(auth_quickaclcheck($pageID) >= AUTH_EDIT)
			$xhtml .= '<div class="secedit">' . html_btn('secedit', $pageID, '', array('do'=>'edit', 'rev'=>'', 'post')) . '</div>';
		// Заменяем name и id у всех якорей на заголовках, т.к. они могут совпадать с основной страницей
		$xhtml = preg_replace('/(<h.+?><a name=")(.+?)(" id=")(.+?)(">.+?<\/a><\/h.+?>)/', '\1__\2\3__\4\5', $xhtml);
	}
	else {
		if (!empty($INFO['namespace']))
			$pageID = $INFO['namespace'] . ':' . $pagename;
		else
			$pageID = $pagename;
		if (auth_quickaclcheck($pageID) >= AUTH_READ) {
			$xhtml = "<p>" . $lang['ubuntu_portal_no_page'] . "</p>";
			// Добавляем кнопочку редактирования если можем редактировать
			if(auth_quickaclcheck($pageID) >= AUTH_EDIT)
				$xhtml .= '<div class="secedit">' . html_btn('secedit', $pageID, '', array('do'=>'edit', 'rev'=>'', 'post')) . '</div>';
		}
		else
			$xhtml = "<p>" . $lang['ubuntu_portal_forbidden'] . "</p>";
	}
	
	print $xhtml;
}
